#ifndef __DOLFIN_FUNCTION_H
#define __DOLFIN_FUNCTION_H

// DOLFIN function interface

#include <dolfin/function/GenericFunction.h>
#include <dolfin/function/Expression.h>
#include <dolfin/function/FunctionAXPY.h>
#include <dolfin/function/Function.h>
#include <dolfin/function/FunctionSpace.h>
#include <dolfin/function/SubSpace.h>
#include <dolfin/function/Constant.h>
#include <dolfin/function/SpecialFunctions.h>
#include <dolfin/function/SpecialFacetFunction.h>
#include <dolfin/function/CCFEMFunctionSpace.h>
#include <dolfin/function/FunctionAssigner.h>
#include <dolfin/function/assign.h>
#include <dolfin/function/CCFEMFunction.h>

#endif
